@@ -26,7 +26,7 @@ use Tk::Pod::Util qw(is_in_path is_interactive detect_window_manager start_brows
 use vars qw($VERSION @ISA @POD $IDX
 	    @tempfiles @gv_pids $terminal_fallback_warn_shown);
 
-$VERSION = '5.31';
+$VERSION = '5.32';
 
 @ISA = qw(Tk::Frame Tk::Pod::SimpleBridge Tk::Pod::Cache);
 
@@ -764,22 +764,8 @@ sub Link_url {
     my ($w,$how,$index,$man,$sec) = @_;
     if (my($lat,$lon) = $man =~ m{^geo:([^,]+),([^,]+)}) {
         DEBUG and warn "Translate geo URI $man\n";
-        # XXX currently hardcoded to Wikipedia's GeoHack page, maybe make
-        # configurable
-        my $ddd2dms = sub {
-            my($ddd) = @_;
-	    my $north_east = $ddd >= 0;
-	    $ddd = -$ddd if !$north_east;
-	    my $deg = int($ddd);
-	    my $min = ($ddd-$deg)*60;
-	    my $sec = ($min-int($min))*60;
-	    $min = int($min);
-	    (($north_east ? $deg : -$deg), $min, $sec);
-	};
-	my $lat_sgn = $lat < 0 ? do { $lat *= -1; "S" } : "N";
-	my $lon_sgn = $lon < 0 ? do { $lon *= -1; "W" } : "E";
-        $man = "http://toolserver.org/~geohack/geohack.php?params="
-	    . join("_", $ddd2dms->($lat), $lat_sgn, $ddd2dms->($lon), $lon_sgn);
+        # XXX currently hardcoded to OSM, maybe make configurable
+        $man = "http://www.openstreetmap.org/?mlat=$lat&mlon=$lon";
     }
     DEBUG and warn "Start browser with $man\n";
     start_browser($man);
@@ -1684,9 +1670,10 @@ Nick Ing-Simmons <F<nick@ni-s.u-net.com>>
 
 Current maintainer is Slaven ReziE<0x107> <F<slaven@rezic.de>>.
 
-Copyright (c) 1998 Nick Ing-Simmons.  All rights reserved.  This program
-is free software; you can redistribute it and/or modify it under the same
-terms as Perl itself.
+Copyright (c) 1998 Nick Ing-Simmons.
+Copyright (c) 2015 Slaven Rezic.
+All rights reserved. This program is free software; you can
+redistribute it and/or modify it under the same terms as Perl itself.
 
 =cut
 
